Index: src/gpu/GrRenderTargetPriv.h |
diff --git a/src/gpu/GrRenderTargetPriv.h b/src/gpu/GrRenderTargetPriv.h |
index 922d9b3071317b952561d15167c4995ddbe60672..19e72637f31459d89edb8d41fac246163b37c9e8 100644 |
--- a/src/gpu/GrRenderTargetPriv.h |
+++ b/src/gpu/GrRenderTargetPriv.h |
@@ -32,10 +32,10 @@ public: |
int numStencilBits() const; |
- // Finds a render target's multisample specs. The stencil settings are only needed in case the |
- // info isn't cached and we need to flush the draw state in order to query it. They are not |
- // expected to affect the multisample information itself. |
- const GrGpu::MultisampleSpecs& getMultisampleSpecs(const GrStencilSettings& stencil) const; |
+ // Finds a render target's multisample specs. The pipeline is only needed in case the info isn't |
+ // cached and we need to flush the draw state in order to query it. The pipeline is not expected |
+ // to affect the multisample information itself. |
+ const GrGpu::MultisampleSpecs& getMultisampleSpecs(const GrPipeline&) const; |
typedef GrRenderTarget::Flags Flags; |